@@ -1,5 +1,4 @@
-"boa.plot.close" <-
-function(which = dev.cur())
+"boa.plot.close" <- function(which = dev.cur())
 #-------------------------------------------------------------------------------
 #-------------------------------------------------------------------------------
 {
